@@ -14,7 +14,7 @@ import warnings
 # commands
 
 pattern = "(?:" + "|".join([
-        r"(<<.*?>>=.*?[\n\r]@)",     # code chunk
+        r"[\n\r](<<.*?>>=.*?[\n\r]@)",     # code chunk
         r"(\\[^\s]*{.*?})",          # command
 ]) + ")"
 
@@ -98,9 +98,9 @@ class CodeChunkToken(Token):
     """A Sweave code chunk"""
     def __init__(self, txt):
         """Given the text of the code chunk"""
-        options, self.rest = re.match("<<(.*?)>>=(.*)", txt,
+        options, self.rest = re.search("<<(.*?)>>=(.*)", txt,
                                         re.DOTALL).groups()
-        self.options = re.findall("([^<> ,\=]+)=?([^<> ,]*)", options)
+        self.options = re.findall("([^<> ,\=]+)\s*=?\s*([^<> ,]*)", options)
 
     def convert_knitr(self):
         """
@@ -110,7 +110,7 @@ class CodeChunkToken(Token):
         rest = "\n".join([l for l in self.rest.split("\n")
                             if "setCacheDir" not in l])
 
-        return "<<%s>>=%s" % (",".join(_convert_knitr_options(self.options)),
+        return "\n<<%s>>=%s" % (",".join(_convert_knitr_options(self.options)),
                                         rest)
 
 
